==> Intellect-1.4.6.tar.gz: Intellect-1.4.6/intellect/IO.py <==

"""
Copyright (c) 2011, The MITRE Corporation.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   This product includes software developed by the author.
4. Neither the name of the author nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""


"""
StdOut

Description:
    Contains all utulity method for capturing stdout.

Initial Version:
    Oct 19, 2011

@author: Michael Joseph Walsh
"""

import sys, StringIO, contextlib

@contextlib.contextmanager
def capture_stdout(stdout=None):
    '''
    Used to collect stdout
    '''
    old = sys.stdout

    if stdout is None:
        stdout = StringIO.StringIO()

    sys.stdout = stdout
    yield stdout
    sys.stdout = old

@contextlib.contextmanager
def capture_stderr(stderr=None):
    '''
    Used to collect stderror
    '''
    old = sys.stderr

    if stderr is None:
        stderr = StringIO.StringIO()

    sys.stderr = stderr
    yield stderr
    sys.stderr = old

==> Intellect-1.4.8.2.tar.gz: Intellect-1.4.8.2/intellect/IO.py <==

"""
Copyright (c) 2011, The MITRE Corporation.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   This product includes software developed by the author.
4. Neither the name of the author nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""


"""
StdOut

Description:
    Contains all utulity method for capturing stdout.

Initial Version:
    Oct 19, 2011

@author: Michael Joseph Walsh
"""

import os
import sys
import StringIO

class RedirectStdError(object):
    def __init__(self):
        self._stderr = StringIO.StringIO()

    def __enter__(self):
        self.save_stderr = sys.stderr
        self.save_stderr.flush()
        sys.stderr = self._stderr

        return sys.stderr

    def __exit__(self, exc_type, exc_value, traceback):
        self._stderr.flush()
        sys.stderr = self.save_stderr


class RedirectStdOut(object):
    def __init__(self):
        self._stdout = StringIO.StringIO()

    def __enter__(self):
        self.save_stdout = sys.stdout
        self.save_stdout.flush()
        sys.stdout = self._stdout

        return sys.stdout

    def __exit__(self, exc_type, exc_value, traceback):
        self._stdout.flush();
        sys.stdout = self.save_stdout
